@@ -3,7 +3,7 @@
 crontab.py
 
 Written July 15, 2011 by Josiah Carlson
-Copyright 2011-2020 Josiah Carlson
+Copyright 2011-2021 Josiah Carlson
 Released under the GNU LGPL v2.1 and v3
 available:
 http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
@@ -422,7 +422,7 @@ class CronTab(object):
             attr = attr() % 7
         return self.matchers[index](attr, dt)
 
-    def next(self, now=None, increments=_increments, delta=True, default_utc=WARN_CHANGE):
+    def next(self, now=None, increments=_increments, delta=True, default_utc=WARN_CHANGE, return_datetime=False):
         '''
         How long to wait in seconds before this crontab entry can next be
         executed.
@@ -479,6 +479,9 @@ class CronTab(object):
             "crontab: %r\n" \
             "now: %r", ' '.join(m.input for m in self.matchers), now)
 
+        if return_datetime:
+            return future.replace(tzinfo=tz)
+
         if not delta:
             onow = now = datetime(1970, 1, 1)
 
@@ -492,8 +495,8 @@ class CronTab(object):
 
         return delay.days * 86400 + delay.seconds + delay.microseconds / 1000000.
 
-    def previous(self, now=None, delta=True, default_utc=WARN_CHANGE):
-        return self.next(now, _decrements, delta, default_utc)
+    def previous(self, now=None, delta=True, default_utc=WARN_CHANGE, return_datetime=False):
+        return self.next(now, _decrements, delta, default_utc, return_datetime)
 
     def test(self, entry):
         if isinstance(entry, _number_types):
